import logging
import logging.handlers
import os
from datetime import datetime
import sys


class Logger:
    """
    Logger utility class for application-wide logging with rotation
    """

    def __init__(self, name="SSHFileToCbs", log_level=logging.INFO):
        self.logger = logging.getLogger(name)
        self.logger.setLevel(log_level)

        # Create logs directory if it doesn't exist
        logs_dir = os.path.join(
            os.path.dirname(os.path.dirname(os.path.dirname(__file__))), "logs"
        )
        os.makedirs(logs_dir, exist_ok=True)

        # Set up file handler with rotation
        log_file_path = os.path.join(
            logs_dir, f"{name}_{datetime.now().strftime('%Y%m%d')}.log"
        )
        file_handler = logging.handlers.RotatingFileHandler(
            log_file_path, maxBytes=10485760, backupCount=10  # 10MB
        )

        # Set up console handler
        console_handler = logging.StreamHandler(sys.stdout)

        # Create formatter
        formatter = logging.Formatter(
            "%(asctime)s - %(name)s - %(levelname)s - %(message)s",
            datefmt="%Y-%m-%d %H:%M:%S",
        )

        # Set formatter for handlers
        file_handler.setFormatter(formatter)
        console_handler.setFormatter(formatter)

        # Add handlers to logger
        self.logger.addHandler(file_handler)
        self.logger.addHandler(console_handler)

    def get_logger(self):
        """Returns the logger instance"""
        return self.logger

